%bcond_with gtk3

%define major		11
%define libname		%mklibname lepton %{major}
%define devname		%mklibname lepton -d

%define attr_major	5
%define libattr		%mklibname leptonattrib %{attr_major}
%define devattr		%mklibname leptonattrib -d

%define gui_major	5
%define libgui		%mklibname leptongui %{gui_major}
%define devgui		%mklibname leptongui -d

%define date		20220529
%define rel			1

Name:		lepton-eda
Summary:	A suite of free software tools for electronic design
Version:	1.9.18
Release:	%mkrel 1
Group:		Sciences/Other
License:	GPLv2
Url:		https://github.com/lepton-eda
Source0:	https://github.com/%{name}/%{name}/releases/download/%{version}-%{date}/%{name}-%{version}.tar.gz

BuildRequires:	flex
BuildRequires:	gawk
BuildRequires:	git-core
BuildRequires:	groff
BuildRequires:	libstroke-devel
%if %{with gtk3}
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(gtksheet-4.0)
%else
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(gtkextra-3.0)
%endif
BuildRequires:	pkgconfig(guile-3.0) >= 3.0.6
BuildRequires:	texinfo

## NOTE these are not auto-required:
Requires:		guile3.0 >= 3.0.6
Requires:		%{libname} = %{version}-%{release}
Requires:		%{libattr} = %{version}-%{release}
Requires:		%{libgui} = %{version}-%{release}

Conflicts:		%{_lib}lepton7 < 1.9.14
Conflicts:		%{_lib}leptongui1 < 1.9.14
Conflicts:		%{_lib}leptonattrib2 < 1.9.14

Obsoletes:		libleptonattrib-i18n < 1.9.14

%description
Lepton EDA is a suite of free software tools for designing electronics.
It provides schematic capture, netlisting into over 30 netlist formats, and
many other features.
It was forked from the gEDA/gaf suite in late 2016 by most of its active
developers at that time.

###################
%package -n %{libname}
Summary:		Library files for %{name}
Requires:		liblepton-i18n >= %{version}-%{release}

%description -n %{libname}
Library files for %{name}

###################
%package -n liblepton-i18n
Summary:		Internationalization and locale data for liblepton
BuildArch:		noarch

%description -n liblepton-i18n
Internationalization and locale data for liblepton.

###################
%package -n %{devname}
Summary:		Development files for %{name}
Requires:		%{libname} = %{version}-%{release}
Provides:		%{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains header files needed by developers.

###################
%package -n %{libattr}
Summary:		Attrib editor library files for %{name}-attrib

%description -n %{libattr}
Library files for %{name}-attrib

###################
%package -n %{devattr}
Summary:		Development files for %{name}-attrib
Requires:		%{libattr} = %{version}-%{release}
Provides:		%{name}-attrib-devel = %{version}-%{release}

%description -n  %{devattr}
This package contains header files needed by developers.

###################
%package -n %{libgui}
Summary:		GUI library files

%description -n  %{libgui}
Library files for %{name}-gui

###################
%package -n %{devgui}
Summary:		Development files for %{name}-gui
Requires:		%{libgui} = %{version}-%{release}
Provides:		%{name}-gui-devel = %{version}-%{release}

%description -n %{devgui}
This package contains header files needed by developers.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
autoreconf --install --force --verbose

%configure %{?_with_gtk3} \
  USE_LDCONFIG=/usr/sbin/ldconfig \
  --disable-update-xdg-database
  
## TODO try to precompile most guile modules:
## https://github.com/lepton-eda/lepton-eda/issues/727#issuecomment-755294449

%make_build

%install
%make_install

# Symlink library files to guile extensions dir:
mkdir -p %{buildroot}%{_libdir}/guile/3.0/extensions
ln -s %{_libdir}/liblepton.so.%{major} %{buildroot}%{_libdir}/guile/3.0/extensions/liblepton.so
ln -s %{_libdir}/libleptonattrib.so.%{attr_major} %{buildroot}%{_libdir}/guile/3.0/extensions/libleptonattrib.so
ln -s %{_libdir}/libleptongui.so.%{gui_major} %{buildroot}%{_libdir}/guile/3.0/extensions/libleptongui.so

find %{buildroot} -name "*.la" -delete

%find_lang liblepton --all-name

%files
%{_bindir}/*
%{_docdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/mime/packages/liblepton.xml
%{_datadir}/applications/*.desktop
%{_infodir}/*
%{_mandir}/man1/*
%{_iconsdir}/hicolor/*/*/*.{svg,png}
%{_libdir}/guile/3.0/extensions/*

%files -n %{libname}
%{_libdir}/liblepton.so.%{major}{,.*}

%files -n liblepton-i18n -f liblepton.lang

%files -n %{devname}
%{_includedir}/liblepton/
%{_libdir}/pkgconfig/liblepton.pc
%{_libdir}/liblepton.so

%files -n %{libattr}
%{_libdir}/libleptonattrib.so.%{attr_major}{,.*}

%files -n %{devattr}
%{_includedir}/libleptonattrib/
%{_libdir}/pkgconfig/libleptonattrib.pc
%{_libdir}/libleptonattrib.so

%files -n %{libgui}
%{_libdir}/libleptongui.so.%{gui_major}{,.*}

%files -n %{devgui}
%{_libdir}/pkgconfig/libleptongui.pc
%{_libdir}/libleptongui.so


%changelog
* Wed Aug 03 2022 barjac <barjac> 1.9.18-1.mga9
+ Revision: 1874801
- new version 1.9.18

* Sun Mar 27 2022 umeabot <umeabot> 1.9.17-20211219.2.mga9
+ Revision: 1828859
- Mageia 9 Mass Rebuild

* Thu Jan 20 2022 barjac <barjac> 1.9.17-20211219.1.mga9
+ Revision: 1769275
- revert name change until next time
- Remove date from package name

* Wed Jan 19 2022 barjac <barjac> 1.9.17-20211219.0.5.mga9
+ Revision: 1769001
- new version 1.9.17
- try to fix runtime errors by removing hack and profile.d and exporting USE_LDCONFIG
+ wally <wally>
- drop circular deps

* Fri Oct 08 2021 barjac <barjac> 1.9.16-20210731.1.mga9
+ Revision: 1750010
- new version 1.9.16
- sub pkgs require main package for conflicts
- simplify %%files section
- new majors
- add TODO note in spec (start-up is very slow compiling guile modules)
+ wally <wally>
- move conflicts back to main pkg where all the conflicting files are
- use %%find_lang macro for translations

* Mon May 10 2021 barjac <barjac> 1.9.14-20210407.2.mga9
+ Revision: 1722437
- move conflicts to specific sub-packages
- make conflicts exact versions
+ wally <wally>
- fix guile dynamic lib loading

* Mon May 03 2021 barjac <barjac> 1.9.14-20210407.1.mga9
+ Revision: 1721153
- new version 1.9.14
- move guile extensions to main package
- dont use find_lang
- add conflicts for moved files
- obsolete one removed sub-package
- require new guile version

* Fri Dec 18 2020 barjac <barjac> 1.9.13-20201211.1.mga8
+ Revision: 1660939
- drop mkrel -c

* Sat Dec 12 2020 barjac <barjac> 1.9.13-0.20201211.1.mga8
+ Revision: 1655742
- new version 1.9.13
- adjust files list for info

* Sat Dec 05 2020 wally <wally> 1.9.12-20201204.2.mga8
+ Revision: 1652767
- disable xdg database updates during the build

* Sat Dec 05 2020 wally <wally> 1.9.12-20201204.1.mga8
+ Revision: 1652754
- new version 1.9.12
- drop libleptonrenderer (merged into liblepton)
- split out translations

* Sun Nov 29 2020 wally <wally> 1.9.11-0.20201005.2.mga8
+ Revision: 1650211
- switch to guile3.0

* Sun Oct 18 2020 barjac <barjac> 1.9.11-0.20201005.1.mga8
+ Revision: 1636792
- Set rel to 1
- add requires to main package on libs
- symlink libs in guile ext dir
- add LIBLEPTON env var in profile.d/lepton-eda
- move .so back into devel pkgs
- move .so files from dev to lib pkgs to fix runtime
- minor tweaks
- start libification
- patch tEDAx export (upstream bugfix)

* Thu Oct 08 2020 barjac <barjac> 1.9.11-0.20201005.0.1.mga8
+ Revision: 1632883
- new package initial import

